==> msmtp-scripts-1.2.4.tar.gz: msmtp-scripts-1.2.4/tests/scripts/t00520-test-conn-tests.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-ping-con.rc

TS=PASS

echo "Subject: test ping fast conn test
       
Test fast ping connectivity test" | /usr/bin/msmtpq-ng root
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Fast ping test succeeds"

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-nc-fail.rc

echo "Subject: test ping fast conn test fail
       
Test fast ping connectivity test fail" | /usr/bin/msmtpq-ng root
MCTRC=$?

if [ "$MCTRC" != "75" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Fast ping test fails on 198.51.100.0 (TEST-NET-2) which should be  non-routable"

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-nc-con.rc

echo "Subject: test netcat conn test
       
Test netcat ping connectivity test" | /usr/bin/msmtpq-ng root
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Netcat test succeeds"

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-no-con.rc

echo "Subject: test no conn test
       
Test no connectivity test" | /usr/bin/msmtpq-ng root
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: No connectivity test test succeeds"

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-nc-fail.rc

/usr/bin/msmtpq-ng -q
MCTRC=$?

if [ "$MCTRC" != "75" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Running queue fails on connectivity to 198.51.100.0 (TEST-NET-2) which should be  non-routable"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi

==> msmtp-scripts-1.2.5.1.tar.gz: msmtp-scripts-1.2.5.1/tests/scripts/t00520-test-conn-tests.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-ping-con.rc

TS=PASS


echo "Subject: test ping fast conn test

Test fast ping connectivity test" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}2-1 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}2-1" root
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Fast ping test succeeds"

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-nc-fail.rc

echo "Subject: test ping fast conn test fail

Test fast ping connectivity test fail" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}2-2 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}2-2" root
MCTRC=$?

if [ "$MCTRC" != "75" ]; then
	echo $MCTRC
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Fast ping test fails on 198.51.100.0 (TEST-NET-2) which should be  non-routable"

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-nc-con.rc

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

echo "Subject: test netcat conn test

Test netcat ping connectivity test" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}2-3 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}2-3" root
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

echo "$TS: Netcat test succeeds"

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-no-con.rc

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

echo "Subject: test no conn test

Test no connectivity test" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}2-4 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}2-4" root
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: No connectivity test test succeeds"

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-nc-fail.rc

echo "Subject: test ping fast conn test fail

Test fast ping connectivity test fail" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}2-5 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}2-5" root

/usr/bin/msmtpq-ng -q
MCTRC=$?

if [ "$MCTRC" != "75" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Running queue fails on connectivity to 198.51.100.0 (TEST-NET-2) which should be  non-routable"

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
